@@ -4,5 +4,5 @@ router = APIRouter()
 
 
 @router.get("", status_code=200, include_in_schema=False)
-async def ready():
+async def is_ready():
     return {"ready": True}
